qc_water_quality.RdThis function checks if the following parameters are within range, have a reasonable rate of change, do not flat line or have sensor drift: temperature, dissolved_oxygen, pH, conductivity, turbidity. The parameters should be spelled as listed.
Data frame with columns: datetime, parameter, value, site_id
Numeric vector of min/max acceptable temperature (°C)
Numeric vector of min/max acceptable DO (mg/L)
Numeric vector of min/max acceptable pH
Numeric vector of min/max acceptable conductivity (μS/cm)
Numeric vector of min/max acceptable turbidity (NTU)
Integer, number of days to check for drift
List with flags, summary, and plots